# PyWren

[![Build Status](https://travis-ci.org/pywren/pywren.svg?branch=master)](https://travis-ci.org/pywren/pywren)

> The wrens are mostly small, brownish passerine birds in the mainly New World family Troglodytidae. ... Most wrens are small and rather inconspicuous, except for their loud and often complex songs. - Wikipedia

PyWren -- it's like a mini condor, in the cloud, for often-complex calls. You can get up to 40 TFLOPS peak from AWS Lambda:

![Benchmark](https://raw.githubusercontent.com/pywren/pywren/master/pywren.gflops.png)

This is the development site. Learn more at [pywren.io](http://pywren.io). 

